from _typeshed import Incomplete

class Dialect:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        header: bool = True,
        delimiter: str = ",",
        annotations: Incomplete | None = None,
        comment_prefix: str = "#",
        date_time_format: str = "RFC3339",
    ) -> None: ...
    @property
    def header(self): ...
    @header.setter
    def header(self, header) -> None: ...
    @property
    def delimiter(self): ...
    @delimiter.setter
    def delimiter(self, delimiter) -> None: ...
    @property
    def annotations(self): ...
    @annotations.setter
    def annotations(self, annotations) -> None: ...
    @property
    def comment_prefix(self): ...
    @comment_prefix.setter
    def comment_prefix(self, comment_prefix) -> None: ...
    @property
    def date_time_format(self): ...
    @date_time_format.setter
    def date_time_format(self, date_time_format) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

class TypeWithDefault(type):
    def __init__(cls, name, bases, dct) -> None: ...
    def __call__(cls): ...
    def set_default(cls, default) -> None: ...

class Configuration(metaclass=TypeWithDefault):
    host: str
    temp_folder_path: Incomplete
    api_key: Incomplete
    api_key_prefix: Incomplete
    username: str
    password: str
    loggers: Incomplete
    logger_stream_handler: Incomplete
    logger_file_handler: Incomplete
    verify_ssl: bool
    ssl_ca_cert: Incomplete
    cert_file: Incomplete
    cert_key_file: Incomplete
    cert_key_password: Incomplete
    assert_hostname: Incomplete
    ssl_context: Incomplete
    connection_pool_maxsize: Incomplete
    timeout: Incomplete
    auth_basic: bool
    proxy: Incomplete
    proxy_headers: Incomplete
    safe_chars_for_path_param: str
    logger_formatter: Incomplete
    def __init__(self) -> None: ...
    @property
    def logger_file(self): ...
    @logger_file.setter
    def logger_file(self, value) -> None: ...
    @property
    def debug(self): ...
    @debug.setter
    def debug(self, value): ...
    @property
    def logger_format(self): ...
    @logger_format.setter
    def logger_format(self, value) -> None: ...
    def get_api_key_with_prefix(self, identifier): ...
    def get_basic_auth_token(self): ...
    def auth_settings(self): ...
    def to_debug_report(self): ...
    def update_request_header_params(self, path: str, params: dict[Incomplete, Incomplete]): ...
    def update_request_body(self, path: str, body): ...



from _typeshed import Incomplete

class TemplateExportByIDOrgIDs:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, org_id: Incomplete | None = None, resource_filters: Incomplete | None = None) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def resource_filters(self): ...
    @resource_filters.setter
    def resource_filters(self, resource_filters) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
